Index: webrtc/p2p/base/transport.h |
diff --git a/webrtc/p2p/base/transport.h b/webrtc/p2p/base/transport.h |
index 13c8431a67d3b23e74c9f6db028879917fad5eb8..84581c8e7b71c4169f38e21a7b17517407bf3abc 100644 |
--- a/webrtc/p2p/base/transport.h |
+++ b/webrtc/p2p/base/transport.h |
@@ -139,9 +139,8 @@ struct TransportStats { |
// Information about ICE configuration. |
struct IceConfig { |
- // The ICE connection receiving timeout value. |
- // TODO(honghaiz): Remove suffix _ms to be consistent. |
- int receiving_timeout_ms = -1; |
+ // The ICE connection receiving timeout value in milliseconds. |
+ int receiving_timeout = -1; |
// Time interval in milliseconds to ping a backup connection when the ICE |
// channel is strongly connected. |
int backup_connection_ping_interval = -1; |
@@ -154,21 +153,21 @@ struct IceConfig { |
// If the current best connection is both writable and receiving, |
// then we will also try hard to make sure it is pinged at this rate |
- // (Default value is a little less than 2 * STRONG_PING_DELAY). |
- int max_strong_delay = -1; |
+ // (Default value is a little less than 2 * STRONG_PING_INTERVAL). |
+ int max_strong_interval = -1; |
IceConfig() {} |
- IceConfig(int receiving_timeout, |
+ IceConfig(int receiving_timeout_ms, |
int backup_connection_ping_interval, |
bool gather_continually, |
bool prioritize_most_likely_candidate_pairs, |
- int max_strong_delay) |
- : receiving_timeout_ms(receiving_timeout), |
+ int max_strong_interval_ms) |
+ : receiving_timeout(receiving_timeout_ms), |
backup_connection_ping_interval(backup_connection_ping_interval), |
gather_continually(gather_continually), |
prioritize_most_likely_candidate_pairs( |
prioritize_most_likely_candidate_pairs), |
- max_strong_delay(max_strong_delay) {} |
+ max_strong_interval(max_strong_interval_ms) {} |
}; |
bool BadTransportDescription(const std::string& desc, std::string* err_desc); |